@@ -142,6 +142,22 @@ ews_populate_string_list (EContact *contact,
 	g_list_free (l_values);
 }
 
+static void
+ews_populate_cert (EContact *contact,
+                    EContactField field,
+                    gpointer value,
+                    gpointer user_data)
+{
+	GSList *list = value;
+	GBytes *bytes = list->data;
+	EContactCert cert;
+
+	cert.data = (gpointer) g_bytes_get_data (bytes, &cert.length);
+	cert.length = g_bytes_get_size (bytes);
+
+	e_contact_set (contact, E_CONTACT_X509_CERT, &cert);
+}
+
 static void
 ews_populate_photo (EContact *contact,
                     EContactField field,
@@ -215,7 +231,10 @@ static const struct prop_field_mapping {
 	{EWS_PT_PAGER_NUMBER, E_CONTACT_PHONE_PAGER, ews_populate_simple_string},
 	{EWS_PT_COMMENT, E_CONTACT_NOTE, ews_populate_simple_string},
 	{EWS_PT_DL_MEMBERS, E_CONTACT_EMAIL, ews_populate_string_list},
-	{EWS_PT_THUMBNAIL_PHOTO, E_CONTACT_PHOTO, ews_populate_photo}
+	{EWS_PT_THUMBNAIL_PHOTO, E_CONTACT_PHOTO, ews_populate_photo},
+	{EWS_PT_OFFICE_LOCATION, E_CONTACT_OFFICE, ews_populate_simple_string},
+	{EWS_PT_X509_CERT, E_CONTACT_X509_CERT, ews_populate_cert},
+	{EWS_PT_SEND_RICH_INFO, E_CONTACT_WANTS_HTML, ews_populate_simple_string},
 };
 
 static void
@@ -596,35 +615,31 @@ ews_decode_uint32 (EwsOabDecoder *eod,
 	return ret;
 }
 
-static gchar *
+static GBytes *
 ews_decode_binary (EwsOabDecoder *eod,
                    GCancellable *cancellable,
                    GError **error)
 {
 	EwsOabDecoderPrivate *priv = GET_PRIVATE (eod);
 	guint32 len;
-	gchar *binary, *filename = NULL;
-	gint fd = 0;
+	gchar *binary;
+	GBytes *val = NULL;
 
 	len = ews_decode_uint32 (eod, cancellable, error);
 	if (*error)
 		return NULL;
-
 	binary = g_malloc (len);
 	g_input_stream_read (G_INPUT_STREAM (priv->fis), binary, len, cancellable, error);
-	if (*error)
+	if (*error) {
+		g_free (binary);
 		goto exit;
+	}
 
-	filename = g_build_filename (priv->cache_dir, "XXXXXX", NULL);
-	fd = g_mkstemp (filename);
-	g_file_set_contents (filename, binary, len, error);
+	val = g_bytes_new_take (binary, len);
+	binary = NULL;
 
 exit:
-	if (binary)
-		g_free (binary);
-	close (fd);
-
-	return filename;
+	return val;
 }
 
 static gpointer
@@ -675,7 +690,7 @@ ews_decode_oab_prop (EwsOabDecoder *eod,
 		case EWS_PTYP_BINARY:
 		{
 			ret_val = ews_decode_binary (eod, cancellable, error);
-			d (g_print ("prop id %X prop type: binary value %s \n", prop_id, (gchar *) ret_val);)
+			d (g_print ("prop id %X prop type: binary size %zd \n", prop_id, g_bytes_get_size ((GBytes *)ret_val)));
 			break;
 		}
 		case EWS_PTYP_MULTIPLEINTEGER32:
@@ -706,21 +721,30 @@ ews_decode_oab_prop (EwsOabDecoder *eod,
 						g_slist_free (list);
 						return NULL;
 					}
+				} else if (prop_type == EWS_PTYP_MULTIPLEBINARY) {
+					GBytes *val;
+
+					val = ews_decode_binary (eod, cancellable, error);
+					if (!val) {
+						g_slist_foreach (list, (GFunc) g_bytes_unref, NULL);
+						g_slist_free (list);
+						return NULL;
+					}
+
+					d (g_print ("prop id %X prop type: multi-bin size %zd\n", prop_id, g_bytes_get_size (val)));
+
+					list = g_slist_prepend (list, val);
 				} else {
 					gchar *val;
 
-					if (prop_type == EWS_PTYP_MULTIPLEBINARY) {
-						val = ews_decode_binary (eod, cancellable, error);
-					} else {
-						val = ews_oab_read_upto (G_INPUT_STREAM (priv->fis), '\0', cancellable, error);
-					}
-
+					val = ews_oab_read_upto (G_INPUT_STREAM (priv->fis), '\0', cancellable, error);
 					if (!val) {
 						g_slist_foreach (list, (GFunc) g_free, NULL);
 						g_slist_free (list);
 						return NULL;
 					}
 
+					d (g_print ("prop id %X prop type: multi-str '%s'\n", prop_id, val));
 					list = g_slist_prepend (list, val);
 				}
 
@@ -738,9 +762,7 @@ ews_decode_oab_prop (EwsOabDecoder *eod,
 }
 
 static void
-ews_destroy_oab_prop (guint32 prop_id,
-                      gpointer val,
-                      gboolean delete_files)
+ews_destroy_oab_prop (guint32 prop_id, gpointer val)
 {
 	guint32 prop_type;
 
@@ -750,14 +772,17 @@ ews_destroy_oab_prop (guint32 prop_id,
 		case EWS_PTYP_INTEGER32:
 		case EWS_PTYP_BOOLEAN:
 			break;
+		case EWS_PTYP_BINARY:
+			g_bytes_unref(val);
+			break;
 		case EWS_PTYP_STRING8:
 		case EWS_PTYP_STRING:
-		case EWS_PTYP_BINARY:
 			g_free ((gchar *) val);
 			break;
 		case EWS_PTYP_MULTIPLEBINARY:
-			if (delete_files)
-				g_slist_foreach ((GSList *) val, (GFunc) g_unlink, NULL);
+			g_slist_foreach ((GSList *) val, (GFunc) g_bytes_unref, NULL);
+			g_slist_free ((GSList *) val);
+			break;
 		case EWS_PTYP_MULTIPLESTRING8:
 		case EWS_PTYP_MULTIPLESTRING:
 			g_slist_foreach ((GSList *) val, (GFunc) g_free, NULL);
@@ -910,10 +935,7 @@ ews_decode_addressbook_record (EwsOabDecoder *eod,
 			else
 				prop_map[i - 1].defered_populate_function (dset, prop_id, val);
 		}
-
-		/* delete the binary file if we do not have the property in the index or if there
-		 * was an error */
-		ews_destroy_oab_prop (prop_id, val, (*error || !index) ? TRUE : FALSE);
+		ews_destroy_oab_prop (prop_id, val);
 		if (*error)
 			goto exit;
 	}
@@ -1153,78 +1175,3 @@ ews_oab_decoder_get_contact_from_offset (EwsOabDecoder *eod,
 	return contact;
 }
 
-#ifdef TEST_BUILD
-
-struct _db_data {
-	GSList *contact_collector;
-	guint collected_length;
-	EBookBackendSqliteDB *summary;
-	const gchar *folderid;
-};
-
-static void
-ews_test_store_contact (EContact *contact,
-                        goffset offset,
-                        guint percent,
-                        gpointer user_data,
-                        GError **error)
-{
-	struct _db_data *data = (struct _db_data *) user_data;
-
-	data->contact_collector = g_slist_prepend (data->contact_collector, g_object_ref (contact));
-	data->collected_length += 1;
-
-	if (data->collected_length == 1000 || percent >= 100) {
-		data->contact_collector = g_slist_reverse (data->contact_collector);
-		e_book_backend_sqlitedb_add_contacts (data->summary, data->folderid, data->contact_collector, FALSE, error);
-		g_print ("percent complete %d \n", percent);
-
-		g_slist_foreach (data->contact_collector, (GFunc) g_object_unref, NULL);
-		g_slist_free (data->contact_collector);
-		data->contact_collector = NULL;
-		data->collected_length = 0;
-	}
-}
-
-gint
-main (gint argc,
-      gchar *argv[])
-{
-	EBookBackendSqliteDB *summary;
-	EwsOabDecoder *eod;
-	GError *err = NULL;
-	GTimer *timer;
-	struct _db_data data;
-
-	g_type_init ();
-
-	if (argc != 3) {
-		g_print ("Pass the oab filename  and cache dir as argument \n");
-		return -1;
-	}
-
-	summary = e_book_backend_sqlitedb_new (argv[2], "dum", "de", "dum", TRUE, NULL);
-	eod = ews_oab_decoder_new (argv[1], argv[2], &err);
-
-	data.contact_collector = NULL;
-	data.collected_length = 0;
-	data.summary = summary;
-	data.folderid = "de";
-
-	timer = g_timer_new ();
-	g_timer_start (timer);
-	if (!ews_oab_decoder_decode (eod, ews_test_store_contact, &data, NULL, &err)) {
-		g_print ("Unable to decode %s \n", err->message);
-	}
-	g_timer_stop (timer);
-	g_print ("Time elapsed %lf \n", g_timer_elapsed (timer, NULL));
-
-	if (err)
-		g_clear_error (&err);
-
-	g_object_unref (eod);
-	g_object_unref (summary);
-
-	return 0;
-}
-#endif /* TEST_BUILD */
