@@ -200,6 +200,11 @@ typedef struct {
 	gpointer field_uri;
 } EwsSortOrder;
 
+typedef struct {
+	gchar *id;
+	gsize len;
+} EwsPhotoAttachmentInfo;
+
 void		ews_oal_free			(EwsOAL *oal);
 void		ews_oal_details_free		(EwsOALDetails *details);
 
@@ -322,6 +327,13 @@ gboolean	e_ews_connection_find_folder_items_sync
 						 GCancellable *cancellable,
 						 GError **error);
 
+EEwsServerVersion
+		e_ews_connection_get_server_version
+						(EEwsConnection *cnc);
+gboolean	e_ews_connection_satisfies_server_version
+						(EEwsConnection *cnc,
+						 EEwsServerVersion versio);
+
 void		e_ews_connection_get_items	(EEwsConnection *cnc,
 						 gint pri,
 						 const GSList *ids,
@@ -675,38 +687,43 @@ void		e_ews_connection_create_attachments
 						 gint pri,
 						 const EwsId *parent,
 						 const GSList *files,
+						 gboolean is_contact_photo,
 						 GCancellable *cancellable,
 						 GAsyncReadyCallback callback,
 						 gpointer user_data);
-GSList *	e_ews_connection_create_attachments_finish
+gboolean	e_ews_connection_create_attachments_finish
 						(EEwsConnection *cnc,
 						 gchar **change_key,
+						 GSList **attachments_ids,
 						 GAsyncResult *result,
 						 GError **error);
-GSList *	e_ews_connection_create_attachments_sync
+gboolean	e_ews_connection_create_attachments_sync
 						(EEwsConnection *cnc,
 						 gint pri,
 						 const EwsId *parent,
 						 const GSList *files,
+						 gboolean is_contact_photo,
 						 gchar **change_key,
+						 GSList **attachments_ids,
 						 GCancellable *cancellable,
 						 GError **error);
 
 void		e_ews_connection_delete_attachments
 						(EEwsConnection *cnc,
 						 gint pri,
-						 const GSList *ids,
+						 const GSList *attachments_ids,
 						 GCancellable *cancellable,
 						 GAsyncReadyCallback callback,
 						 gpointer user_data);
-GSList *	e_ews_connection_delete_attachments_finish
+gboolean	e_ews_connection_delete_attachments_finish
 						(EEwsConnection *cnc,
 						 GAsyncResult *result,
+						 GSList **parents_ids,
 						 GError **error);
-GSList *	e_ews_connection_delete_attachments_sync
+gboolean	e_ews_connection_delete_attachments_sync
 						(EEwsConnection *cnc,
 						 gint pri,
-						 const GSList *ids,
+						 const GSList *attachments_ids,
 						 GSList **parents_ids,
 						 GCancellable *cancellable,
 						 GError **error);
@@ -723,12 +740,12 @@ void		e_ews_connection_get_attachments
 						 GCancellable *cancellable,
 						 GAsyncReadyCallback callback,
 						 gpointer user_data);
-GSList *	e_ews_connection_get_attachments_finish
+gboolean	e_ews_connection_get_attachments_finish
 						(EEwsConnection *cnc,
 						 GAsyncResult *result,
 						 GSList **items,
 						 GError **error);
-GSList *	e_ews_connection_get_attachments_sync
+gboolean	e_ews_connection_get_attachments_sync
 						(EEwsConnection *cnc,
 						 gint pri,
 						 const gchar *comp_uid,
